@@ -5,6 +5,7 @@ setup <- function()
     C <- as.matrix(read.table(system.file("cec_tests", "centers1.data", package="CEC")))
     expected <- dget(system.file("cec_tests", "cec1.dp", package="CEC"))  
 }
+
 test.clustering.mouse1 <- function()
 {  
     CEC <- cec(M, C)
@@ -14,8 +15,5 @@ test.clustering.mouse1 <- function()
     CEC:::checkNumericMatrixEquals(M, CEC$data, msg="Data")
     CEC:::checkNumericVectorEquals(expected$probability, CEC$probability, msg="Probability")
     CEC:::checkNumericVectorEquals(expected$nclusters, CEC$nclusters, msg="Number of clusters")
-    CEC:::checkNumericVectorEquals(expected$final.cost.function, CEC$final.cost.function, msg="Final cost function")
-    CEC:::checkNumericVectorEquals(expected$final.nclusters, CEC$final.nclusters, msg="Final number of clusters")
     CEC:::checkNumericVectorEquals(expected$iterations, CEC$iterations, msg="Iterations")
-    
 }
